@@ -1,31 +1,25 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
-    Copyright (C) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTCPSOCKET_H
 #define KTCPSOCKET_H
 
-#include <QSslSocket>
-#include <QSslConfiguration>
-
 #include "kiocore_export.h"
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 65)
+#include "ksslerroruidata.h"
+
+#include <QSslConfiguration>
+#include <QSslSocket>
+
+// All classes here are deprecated, no need for clazy to bother
+// clazy:excludeall=overloaded-signal,fully-qualified-moc-types
+
 /*
   Notes on QCA::TLS compatibility
   In order to check for all validation problems as far as possible we need to use:
@@ -37,17 +31,20 @@
 
 class KSslKeyPrivate;
 
-class KIOCORE_EXPORT KSslKey
+/** SSL Key
+ *  @deprecated since 5.65, use QSslKey instead.
+ */
+class KIOCORE_DEPRECATED_VERSION(5, 65, "Use QSslKey") KIOCORE_EXPORT KSslKey
 {
 public:
     enum Algorithm {
         Rsa = 0,
         Dsa,
-        Dh
+        Dh,
     };
     enum KeySecrecy {
         PublicKey,
-        PrivateKey
+        PrivateKey,
     };
 
     KSslKey();
@@ -60,13 +57,17 @@ public:
     bool isExportable() const;
     KeySecrecy secrecy() const;
     QByteArray toDer() const;
+
 private:
     KSslKeyPrivate *const d;
 };
 
 class KSslCipherPrivate;
 
-class KIOCORE_EXPORT KSslCipher
+/** SSL Cipher
+ *  @deprecated since 5.65, use QSslCipher instead.
+ */
+class KIOCORE_DEPRECATED_VERSION(5, 65, "Use QSslCipher") KIOCORE_EXPORT KSslCipher
 {
 public:
     KSslCipher();
@@ -94,7 +95,10 @@ private:
 class KSslErrorPrivate;
 class KTcpSocket;
 
-class KIOCORE_EXPORT KSslError
+/** To be replaced by QSslError.
+ *  @deprecated since 5.65
+ */
+class KIOCORE_DEPRECATED_VERSION(5, 65, "Use QSslError") KIOCORE_EXPORT KSslError
 {
 public:
     enum Error {
@@ -111,10 +115,15 @@ public:
         UntrustedCertificate,
         NoPeerCertificate,
         HostNameMismatch,
-        PathLengthExceeded
+        PathLengthExceeded,
     };
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 63)
+    /** @deprecated since 5.63, use the QSslError ctor instead. */
+    KIOCORE_DEPRECATED_VERSION(5, 63, "Use KSslError(const QSslError &)")
     KSslError(KSslError::Error error = NoError, const QSslCertificate &cert = QSslCertificate());
-    KSslError(const QSslError &error);  //### explicit yes or no?
+#endif
+    KSslError(const QSslError &error);
     KSslError(const KSslError &other);
     ~KSslError();
     KSslError &operator=(const KSslError &other);
@@ -122,23 +131,32 @@ public:
     Error error() const;
     QString errorString() const;
     QSslCertificate certificate() const;
+    /**
+     * Returns the QSslError wrapped by this KSslError.
+     * @since 5.63
+     */
+    QSslError sslError() const;
+
 private:
     KSslErrorPrivate *const d;
 };
 
-//consider killing more convenience functions with huge signatures
+// consider killing more convenience functions with huge signatures
 //### do we need setSession() / session() ?
 
-//BIG FAT TODO: do we keep openMode() up to date everywhere it can change?
+// BIG FAT TODO: do we keep openMode() up to date everywhere it can change?
 
-//other TODO: limit possible error strings?, SSL key stuff
+// other TODO: limit possible error strings?, SSL key stuff
 
-//TODO protocol (or maybe even application?) dependent automatic proxy choice
+// TODO protocol (or maybe even application?) dependent automatic proxy choice
 
 class KTcpSocketPrivate;
 class QHostAddress;
 
-class KIOCORE_EXPORT KTcpSocket: public QIODevice
+/** TCP socket.
+ *  @deprecated since 5.65, use QSslSocket instead.
+ */
+class KIOCORE_DEPRECATED_VERSION(5, 65, "Use QSslSocket") KIOCORE_EXPORT KTcpSocket : public QIODevice
 {
     Q_OBJECT
 public:
@@ -149,22 +167,22 @@ public:
         ConnectedState,
         BoundState,
         ListeningState,
-        ClosingState
-        //hmmm, do we need an SslNegotiatingState?
+        ClosingState,
+        // hmmm, do we need an SslNegotiatingState?
     };
     enum SslVersion {
         UnknownSslVersion = 0x01,
-        SslV2 = 0x02,
-        SslV3 = 0x04,
+        SslV2 = 0x02, ///< Note: no-op in Qt for a long time
+        SslV3 = 0x04, ///< Note: no-op in Qt for a long time
         TlsV1 = 0x08,
         SslV3_1 = 0x08,
-        TlsV1SslV3 = 0x10,
+        TlsV1SslV3 = 0x10, ///< Note: same as TlsV1_0
         SecureProtocols = 0x20,
         TlsV1_0 = TlsV1,
         TlsV1_1 = 0x40,
         TlsV1_2 = 0x80,
         TlsV1_3 = 0x100,
-        AnySslVersion = SslV2 | SslV3 | TlsV1
+        AnySslVersion = SslV2 | SslV3 | TlsV1,
     };
     Q_DECLARE_FLAGS(SslVersions, SslVersion)
 
@@ -178,7 +196,7 @@ public:
         SocketTimeoutError,
         NetworkError,
         UnsupportedSocketOperationError,
-        SslHandshakeFailedError                 ///< @since 4.10.5
+        SslHandshakeFailedError, ///< @since 4.10.5
     };
     /*
     The following is based on reading the OpenSSL interface code of both QSslSocket
@@ -215,20 +233,20 @@ public:
     enum EncryptionMode {
         UnencryptedMode = 0,
         SslClientMode,
-        SslServerMode //### not implemented
+        SslServerMode, //### not implemented
     };
     enum ProxyPolicy {
         /// Use the proxy that KProtocolManager suggests for the connection parameters given.
         AutoProxy = 0,
         /// Use the proxy set by setProxy(), if any; otherwise use no proxy.
-        ManualProxy
+        ManualProxy,
     };
 
     KTcpSocket(QObject *parent = nullptr);
     ~KTcpSocket();
 
-    //from QIODevice
-    //reimplemented virtuals - the ones not reimplemented are OK for us
+    // from QIODevice
+    // reimplemented virtuals - the ones not reimplemented are OK for us
     bool atEnd() const override;
     qint64 bytesAvailable() const override;
     qint64 bytesToWrite() const override;
@@ -239,6 +257,7 @@ public:
     bool waitForBytesWritten(int msecs) override;
     //### Document that this actually tries to read *more* data
     bool waitForReadyRead(int msecs = 30000) override;
+
 protected:
     qint64 readData(char *data, qint64 maxSize) override;
     qint64 writeData(const char *data, qint64 maxSize) override;
@@ -246,8 +265,9 @@ Q_SIGNALS:
     /// @since 4.8.1
     /// Forwarded from QSslSocket
     void encryptedBytesWritten(qint64 written);
+
 public:
-    //from QAbstractSocket
+    // from QAbstractSocket
     void abort();
     void connectToHost(const QString &hostName, quint16 port, ProxyPolicy policy = AutoProxy);
     void connectToHost(const QHostAddress &hostAddress, quint16 port, ProxyPolicy policy = AutoProxy);
@@ -261,9 +281,9 @@ public:
     void connectToHost(const QUrl &url, ProxyPolicy policy = AutoProxy);
     void disconnectFromHost();
     Error error() const; //### QAbstractSocket's model is strange. error() should be related to the
-    //current state and *NOT* just report the last error if there was one.
+    // current state and *NOT* just report the last error if there was one.
     QList<KSslError> sslErrors() const; //### the errors returned can only have a subset of all
-    //possible QSslError::SslError enum values depending on backend
+    // possible QSslError::SslError enum values depending on backend
     bool flush();
     bool isValid() const;
     QHostAddress localAddress() const;
@@ -278,23 +298,23 @@ public:
      */
     QNetworkProxy proxy() const;
 #endif
-    qint64 readBufferSize() const; //probably hard to implement correctly
+    qint64 readBufferSize() const; // probably hard to implement correctly
 
 #ifndef QT_NO_NETWORKPROXY
     /**
      * @see: connectToHost()
      */
-    void setProxy(const QNetworkProxy &proxy); //people actually seem to need it
+    void setProxy(const QNetworkProxy &proxy); // people actually seem to need it
 #endif
     void setReadBufferSize(qint64 size);
     State state() const;
     bool waitForConnected(int msecs = 30000);
     bool waitForDisconnected(int msecs = 30000);
 
-    //from QSslSocket
+    // from QSslSocket
     void addCaCertificate(const QSslCertificate &certificate);
-//    bool addCaCertificates(const QString &path, QSsl::EncodingFormat format = QSsl::Pem,
-//                           QRegExp::PatternSyntax syntax = QRegExp::FixedString);
+    //    bool addCaCertificates(const QString &path, QSsl::EncodingFormat format = QSsl::Pem,
+    //                           QRegExp::PatternSyntax syntax = QRegExp::FixedString);
     void addCaCertificates(const QList<QSslCertificate> &certificates);
     QList<QSslCertificate> caCertificates() const;
     QList<KSslCipher> ciphers() const;
@@ -310,12 +330,13 @@ public:
     void setLocalCertificate(const QSslCertificate &certificate);
     void setLocalCertificate(const QString &fileName, QSsl::EncodingFormat format = QSsl::Pem);
     void setPrivateKey(const KSslKey &key);
-    void setPrivateKey(const QString &fileName, KSslKey::Algorithm algorithm = KSslKey::Rsa,
+    void setPrivateKey(const QString &fileName,
+                       KSslKey::Algorithm algorithm = KSslKey::Rsa,
                        QSsl::EncodingFormat format = QSsl::Pem,
                        const QByteArray &passPhrase = QByteArray());
     void setAdvertisedSslVersion(SslVersion version);
-    SslVersion advertisedSslVersion() const;    //always equal to last setSslAdvertisedVersion
-    SslVersion negotiatedSslVersion() const;     //negotiated version; downgrades are possible.
+    SslVersion advertisedSslVersion() const; // always equal to last setSslAdvertisedVersion
+    SslVersion negotiatedSslVersion() const; // negotiated version; downgrades are possible.
     QString negotiatedSslVersionName() const;
     bool waitForEncrypted(int msecs = 30000);
 
@@ -354,7 +375,7 @@ public:
     void setSslConfiguration(const QSslConfiguration &configuration);
 
 Q_SIGNALS:
-    //from QAbstractSocket
+    // from QAbstractSocket
     void connected();
     void disconnected();
     void error(KTcpSocket::Error);
@@ -365,7 +386,7 @@ Q_SIGNALS:
     // only for raw socket state, SSL is separate
     void stateChanged(KTcpSocket::State);
 
-    //from QSslSocket
+    // from QSslSocket
     void encrypted();
     void encryptionModeChanged(EncryptionMode);
     void sslErrors(const QList<KSslError> &errors);
@@ -381,46 +402,13 @@ private:
     Q_PRIVATE_SLOT(d, void reemitStateChanged(QAbstractSocket::SocketState))
     Q_PRIVATE_SLOT(d, void reemitModeChanged(QSslSocket::SslMode))
 
-//debugging H4X
+    // debugging H4X
     void showSslErrors();
 
     friend class KTcpSocketPrivate;
     KTcpSocketPrivate *const d;
 };
 
-/**
- * This class can hold all the necessary data from a KTcpSocket to ask the user
- * to continue connecting in the face of SSL errors.
- * It can be used to carry the data for the UI over time or over thread boundaries.
- *
- * @see: KSslCertificateManager::askIgnoreSslErrors()
- */
-class KIOCORE_EXPORT KSslErrorUiData
-{
-public:
-    /**
-     * Default construct an instance with no useful data.
-     */
-    KSslErrorUiData();
-    /**
-     * Create an instance and initialize it with SSL error data from @p socket.
-     */
-    KSslErrorUiData(const KTcpSocket *socket);
-    /**
-     * Create an instance and initialize it with SSL error data from @p socket.
-     */
-    KSslErrorUiData(const QSslSocket *socket);
-    KSslErrorUiData(const KSslErrorUiData &other);
-    KSslErrorUiData &operator=(const KSslErrorUiData &);
-    /**
-     * Destructor
-     * @since 4.7
-     */
-    ~KSslErrorUiData();
-    class Private;
-private:
-    friend class Private;
-    Private *const d;
-};
+#endif // deprecated since 5.65
 
 #endif // KTCPSOCKET_H
