@@ -12,7 +12,7 @@
 
 #include <QDirIterator>
 
-#include <KDiskFreeSpaceInfo>
+#include <QStorageInfo>
 
 #include "kioglobal_p.h"
 
@@ -21,7 +21,7 @@
 #endif
 
 #include <assert.h>
-#include <errno.h>
+#include <cerrno>
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
 #include <sys/utime.h>
@@ -67,7 +67,7 @@ class KIOPluginForMetaData : public QObject
 
 using namespace KIO;
 
-#define MAX_IPC_SIZE (1024 * 32)
+static constexpr int s_maxIPCSize = 1024 * 32;
 
 static QString readLogFile(const QByteArray &_filename);
 
@@ -342,11 +342,11 @@ void FileProtocol::get(const QUrl &url)
         }
     }
 
-    char buffer[MAX_IPC_SIZE];
+    char buffer[s_maxIPCSize];
     QByteArray array;
 
     while (1) {
-        int n = f.read(buffer, MAX_IPC_SIZE);
+        int n = f.read(buffer, s_maxIPCSize);
         if (n == -1) {
             if (errno == EINTR) {
                 continue;
@@ -917,9 +917,7 @@ void FileProtocol::mount(bool _ro, const char *_fstype, const QString &_dev, con
     }
 #endif /* ! HAVE_VOLMGT */
 #else
-    QString err;
-    err = i18n("mounting is not supported by wince.");
-    error(KIO::ERR_CANNOT_MOUNT, err);
+    error(KIO::ERR_CANNOT_MOUNT, i18n("mounting is not supported by Windows CE."));
 #endif
 }
 
@@ -1158,10 +1156,10 @@ bool FileProtocol::deleteRecursive(const QString &path)
 void FileProtocol::fileSystemFreeSpace(const QUrl &url)
 {
     if (url.isLocalFile()) {
-        const KDiskFreeSpaceInfo spaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(url.toLocalFile());
-        if (spaceInfo.isValid()) {
-            setMetaData(QStringLiteral("total"), QString::number(spaceInfo.size()));
-            setMetaData(QStringLiteral("available"), QString::number(spaceInfo.available()));
+        QStorageInfo storageInfo(url.toLocalFile());
+        if (storageInfo.isValid() && storageInfo.isReady()) {
+            setMetaData(QStringLiteral("total"), QString::number(storageInfo.bytesTotal()));
+            setMetaData(QStringLiteral("available"), QString::number(storageInfo.bytesAvailable()));
 
             finished();
         } else {
