@@ -1,31 +1,19 @@
-/* This file is part of the KDE project
-    Copyright 2010 David Faure <faure@kde.org>
-    Copyright 2012 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2010 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2012 Dawit Alemayehu <adawit@kde.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License or ( at
-   your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-   act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#include <kpassworddialog.h>
+#include <KPasswordDialog>
 #include <QApplication>
-#include <kpasswdserver.h>
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
+#include <kpasswdserver.h>
 
-static const char* sigQueryAuthInfoResult = SIGNAL(queryAuthInfoAsyncResult(qlonglong,qlonglong,KIO::AuthInfo));
-static const char* sigCheckAuthInfoResult = SIGNAL(checkAuthInfoAsyncResult(qlonglong,qlonglong,KIO::AuthInfo));
+static const char *sigQueryAuthInfoResult = SIGNAL(queryAuthInfoAsyncResult(qlonglong, qlonglong, KIO::AuthInfo));
+static const char *sigCheckAuthInfoResult = SIGNAL(checkAuthInfoAsyncResult(qlonglong, qlonglong, KIO::AuthInfo));
 
 // For the retry dialog (and only that one)
 static QDialogButtonBox::StandardButton s_buttonYes = QDialogButtonBox::Yes;
@@ -34,7 +22,7 @@ static QDialogButtonBox::StandardButton s_buttonCancel = QDialogButtonBox::Cance
 Q_DECLARE_METATYPE(QDialogButtonBox::StandardButton)
 Q_DECLARE_METATYPE(QDialog::DialogCode)
 
-static QString getUserNameFrom(const KIO::AuthInfo& auth)
+static QString getUserNameFrom(const KIO::AuthInfo &auth)
 {
     if (auth.username.isEmpty() && !auth.url.userName().isEmpty()) {
         return auth.url.userName();
@@ -103,10 +91,11 @@ private Q_SLOTS:
         QSignalSpy spyQuery(&server, sigQueryAuthInfoResult);
         const qlonglong windowId = 42;
         const qlonglong seqNr = 2;
-        const qlonglong id = server.queryAuthInfoAsync(
-            info,
-            QStringLiteral("<NoAuthPrompt>"), // magic string to avoid a dialog
-            windowId, seqNr, 16 /*usertime*/);
+        const qlonglong id = server.queryAuthInfoAsync(info,
+                                                       QStringLiteral("<NoAuthPrompt>"), // magic string to avoid a dialog
+                                                       windowId,
+                                                       seqNr,
+                                                       16 /*usertime*/);
 
         // Before it is processed, do a check, it will reply delayed.
         QSignalSpy spyCheck(&server, sigCheckAuthInfoResult);
@@ -122,7 +111,7 @@ private Q_SLOTS:
 
         // Now the check will have replied
         QCOMPARE(spyCheck.count(), 1);
-        QCOMPARE(spyCheck[0][0].toLongLong(), id+1); // it was the next request after the query
+        QCOMPARE(spyCheck[0][0].toLongLong(), id + 1); // it was the next request after the query
         KIO::AuthInfo resultCheck = spyCheck[0][2].value<KIO::AuthInfo>();
         QCOMPARE(result.username, resultCheck.username);
         QCOMPARE(result.password, resultCheck.password);
@@ -177,7 +166,7 @@ private Q_SLOTS:
         KPasswdServer server(this);
         server.setWalletDisabled(true);
 
-       // What the app would ask
+        // What the app would ask
         KIO::AuthInfo info;
         info.url = QUrl(QStringLiteral("http://www.example.com"));
 
@@ -201,7 +190,7 @@ private Q_SLOTS:
         KPasswdServer server(this);
         server.setWalletDisabled(true);
 
-       // What the app would ask
+        // What the app would ask
         KIO::AuthInfo info;
         info.url = QUrl(QStringLiteral("http://www.example.com"));
 
@@ -299,10 +288,10 @@ private Q_SLOTS:
         server.setWalletDisabled(true);
 
         QList<KIO::AuthInfo> authInfos;
-        for (int i=0; i < 10; ++i) {
-           KIO::AuthInfo info;
-           info.url = QUrl("http://www.example.com/test" + QString::number(i) + ".html");
-           authInfos << info;
+        for (int i = 0; i < 10; ++i) {
+            KIO::AuthInfo info;
+            info.url = QUrl(QLatin1String("http://www.example.com/test") + QString::number(i) + QLatin1String(".html"));
+            authInfos << info;
         }
 
         // What the user would type
@@ -320,10 +309,10 @@ private Q_SLOTS:
         server.setWalletDisabled(true);
 
         QList<KIO::AuthInfo> authInfos;
-        for (int i=0; i < 10; ++i) {
-           KIO::AuthInfo info;
-           info.url = QUrl("http://www.example.com/test" + QString::number(i) + ".html");
-           authInfos << info;
+        for (int i = 0; i < 10; ++i) {
+            KIO::AuthInfo info;
+            info.url = QUrl(QLatin1String("http://www.example.com/test") + QString::number(i) + QStringLiteral(".html"));
+            authInfos << info;
         }
 
         // What the user would type
@@ -337,26 +326,22 @@ private Q_SLOTS:
 
 private:
     // Checks that no auth is available for @p info
-    bool noCheckAuth(KPasswdServer& server, const KIO::AuthInfo& info)
+    bool noCheckAuth(KPasswdServer &server, const KIO::AuthInfo &info)
     {
         KIO::AuthInfo result;
         checkAuth(server, info, result);
-        return (result.username == info.username)
-            && (result.password == info.password)
-            && !result.isModified();
+        return (result.username == info.username) && (result.password == info.password) && !result.isModified();
     }
 
     // Check that the auth is available and equal to @expectedInfo
-    bool successCheckAuth(KPasswdServer& server, const KIO::AuthInfo& info, const KIO::AuthInfo& expectedInfo)
+    bool successCheckAuth(KPasswdServer &server, const KIO::AuthInfo &info, const KIO::AuthInfo &expectedInfo)
     {
         KIO::AuthInfo result;
         checkAuth(server, info, result);
-        return (result.username == expectedInfo.username)
-            && (result.password == expectedInfo.password)
-            && result.isModified();
+        return (result.username == expectedInfo.username) && (result.password == expectedInfo.password) && result.isModified();
     }
 
-    void checkAuth(KPasswdServer& server, const KIO::AuthInfo& info, KIO::AuthInfo& result)
+    void checkAuth(KPasswdServer &server, const KIO::AuthInfo &info, KIO::AuthInfo &result)
     {
         QSignalSpy spy(&server, sigCheckAuthInfoResult);
         const qlonglong windowId = 42;
@@ -368,41 +353,41 @@ private:
         QCOMPARE(spy.count(), 1);
         // kpasswdserver emits a requestId via dbus, we can't get that id here
         QVERIFY(spy[0][0].toLongLong() >= 0);
-        //QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
+        // QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
         result = spy[0][2].value<KIO::AuthInfo>();
     }
 
-    void queryAuth(KPasswdServer& server, const KIO::AuthInfo& info, KIO::AuthInfo& result)
+    void queryAuth(KPasswdServer &server, const KIO::AuthInfo &info, KIO::AuthInfo &result)
     {
         QSignalSpy spy(&server, sigQueryAuthInfoResult);
         const qlonglong windowId = 42;
         const qlonglong seqNr = 2;
-        const qlonglong id = server.queryAuthInfoAsync(
-            info,
-            QStringLiteral("<NoAuthPrompt>"), // magic string to avoid a dialog
-            windowId, seqNr, 16 /*usertime*/);
+        const qlonglong id = server.queryAuthInfoAsync(info,
+                                                       QStringLiteral("<NoAuthPrompt>"), // magic string to avoid a dialog
+                                                       windowId,
+                                                       seqNr,
+                                                       16 /*usertime*/);
         QVERIFY(id >= 0); // requestId, ever increasing
         if (spy.isEmpty())
             QVERIFY(QSignalSpy(&server, sigQueryAuthInfoResult).wait(1000));
         QCOMPARE(spy.count(), 1);
         QCOMPARE(spy[0][0].toLongLong(), id);
-        //QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
+        // QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
         result = spy[0][2].value<KIO::AuthInfo>();
     }
 
-    void queryAuthWithDialog(KPasswdServer& server, const KIO::AuthInfo& info,
-                             const KIO::AuthInfo& filledInfo, KIO::AuthInfo& result,
+    void queryAuthWithDialog(KPasswdServer &server,
+                             const KIO::AuthInfo &info,
+                             const KIO::AuthInfo &filledInfo,
+                             KIO::AuthInfo &result,
                              QDialogButtonBox::StandardButton retryButton = s_buttonYes,
                              QDialog::DialogCode code = QDialog::Accepted,
-                             const QString& errMsg = QString())
+                             const QString &errMsg = QString())
     {
         QSignalSpy spy(&server, sigQueryAuthInfoResult);
         const qlonglong windowId = 42;
         const qlonglong seqNr = 2;
-        const qlonglong id = server.queryAuthInfoAsync(
-            info,
-            errMsg,
-            windowId, seqNr, 16 /*usertime*/);
+        const qlonglong id = server.queryAuthInfoAsync(info, errMsg, windowId, seqNr, 16 /*usertime*/);
         QVERIFY(id >= 0); // requestId, ever increasing
         QVERIFY(spy.isEmpty());
 
@@ -411,15 +396,16 @@ private:
 
         if (hasErrorMessage) {
             // Retry dialog only knows Yes/No
-            QMetaObject::invokeMethod(this, "checkRetryDialog",
-                                      Qt::QueuedConnection, Q_ARG(QDialogButtonBox::StandardButton, retryButton));
+            QMetaObject::invokeMethod(this, "checkRetryDialog", Qt::QueuedConnection, Q_ARG(QDialogButtonBox::StandardButton, retryButton));
         }
 
         if (!isCancelRetryDialogTest) {
-            QMetaObject::invokeMethod(this, "checkAndFillDialog", Qt::QueuedConnection,
+            QMetaObject::invokeMethod(this,
+                                      "checkAndFillDialog",
+                                      Qt::QueuedConnection,
                                       Q_ARG(KIO::AuthInfo, info),
                                       Q_ARG(KIO::AuthInfo, filledInfo),
-                                      Q_ARG(QDialog::DialogCode, code ));
+                                      Q_ARG(QDialog::DialogCode, code));
         }
         // Force KPasswdServer to process the request now, otherwise the checkAndFillDialog needs a timer too...
         server.processRequest();
@@ -427,17 +413,19 @@ private:
             QVERIFY(QSignalSpy(&server, sigQueryAuthInfoResult).wait(1000));
         QCOMPARE(spy.count(), 1);
         QCOMPARE(spy[0][0].toLongLong(), id);
-        //QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
+        // QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
         result = spy[0][2].value<KIO::AuthInfo>();
         const QString username = (isCancelRetryDialogTest ? QString() : filledInfo.username);
         const QString password = (isCancelRetryDialogTest ? QString() : filledInfo.password);
         QCOMPARE(result.username, username);
         QCOMPARE(result.password, password);
-        QCOMPARE(result.isModified(), retryButton == s_buttonYes && code  == QDialog::Accepted);
+        QCOMPARE(result.isModified(), retryButton == s_buttonYes && code == QDialog::Accepted);
     }
 
-    void concurrentQueryAuthWithDialog(KPasswdServer& server, const QList<KIO::AuthInfo>& infos,
-                                       const KIO::AuthInfo& filledInfo, QList<KIO::AuthInfo>& results,
+    void concurrentQueryAuthWithDialog(KPasswdServer &server,
+                                       const QList<KIO::AuthInfo> &infos,
+                                       const KIO::AuthInfo &filledInfo,
+                                       QList<KIO::AuthInfo> &results,
                                        QDialog::DialogCode code = QDialog::Accepted)
     {
         QSignalSpy spy(&server, sigQueryAuthInfoResult);
@@ -445,19 +433,18 @@ private:
         qlonglong seqNr = 0;
         QList<qlonglong> idList;
 
-        Q_FOREACH(const KIO::AuthInfo& info, infos) {
-            const qlonglong id = server.queryAuthInfoAsync(
-                info,
-                QString(),
-                windowId, seqNr, 16 /*usertime*/);
+        for (const KIO::AuthInfo &info : infos) {
+            const qlonglong id = server.queryAuthInfoAsync(info, QString(), windowId, seqNr, 16 /*usertime*/);
             QVERIFY(id >= 0); // requestId, ever increasing
             idList << id;
         }
 
         QVERIFY(spy.isEmpty());
-        QMetaObject::invokeMethod(this, "checkAndFillDialog", Qt::QueuedConnection,
+        QMetaObject::invokeMethod(this,
+                                  "checkAndFillDialog",
+                                  Qt::QueuedConnection,
                                   Q_ARG(KIO::AuthInfo, infos.first()),
-                                  Q_ARG(KIO::AuthInfo,filledInfo),
+                                  Q_ARG(KIO::AuthInfo, filledInfo),
                                   Q_ARG(QDialog::DialogCode, code));
 
         // Force KPasswdServer to process the request now, otherwise the checkAndFillDialog needs a timer too...
@@ -467,9 +454,9 @@ private:
 
         QCOMPARE(spy.count(), infos.count());
 
-        for(int i = 0, count = spy.count(); i < count; ++i) {
+        for (int i = 0, count = spy.count(); i < count; ++i) {
             QCOMPARE(spy[i][0].toLongLong(), idList.at(i));
-            //QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
+            // QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
             KIO::AuthInfo result = spy[i][2].value<KIO::AuthInfo>();
             QCOMPARE(result.username, filledInfo.username);
             QCOMPARE(result.password, filledInfo.password);
@@ -478,8 +465,10 @@ private:
         }
     }
 
-    void concurrentCheckAuthWithDialog(KPasswdServer& server, const QList<KIO::AuthInfo>& infos,
-                                       const KIO::AuthInfo& filledInfo, QList<KIO::AuthInfo>& results,
+    void concurrentCheckAuthWithDialog(KPasswdServer &server,
+                                       const QList<KIO::AuthInfo> &infos,
+                                       const KIO::AuthInfo &filledInfo,
+                                       QList<KIO::AuthInfo> &results,
                                        QDialog::DialogCode code = QDialog::Accepted)
     {
         QSignalSpy spy(&server, sigQueryAuthInfoResult);
@@ -487,26 +476,25 @@ private:
         qlonglong seqNr = 0;
         QList<qlonglong> idList;
 
-        QListIterator<KIO::AuthInfo> it (infos);
+        QListIterator<KIO::AuthInfo> it(infos);
         if (it.hasNext()) {
-            const qlonglong id = server.queryAuthInfoAsync(
-                it.next(),
-                QString(),
-                windowId, seqNr, 16 /*usertime*/);
+            const qlonglong id = server.queryAuthInfoAsync(it.next(), QString(), windowId, seqNr, 16 /*usertime*/);
             QVERIFY(id >= 0); // requestId, ever increasing
             idList << id;
         }
 
         while (it.hasNext()) {
-            const qlonglong id = server.checkAuthInfoAsync(it.next(), windowId,16 /*usertime*/);
+            const qlonglong id = server.checkAuthInfoAsync(it.next(), windowId, 16 /*usertime*/);
             QVERIFY(id >= 0); // requestId, ever increasing
             idList << id;
         }
 
         QVERIFY(spy.isEmpty());
-        QMetaObject::invokeMethod(this, "checkAndFillDialog", Qt::QueuedConnection,
+        QMetaObject::invokeMethod(this,
+                                  "checkAndFillDialog",
+                                  Qt::QueuedConnection,
                                   Q_ARG(KIO::AuthInfo, infos.first()),
-                                  Q_ARG(KIO::AuthInfo,filledInfo),
+                                  Q_ARG(KIO::AuthInfo, filledInfo),
                                   Q_ARG(QDialog::DialogCode, code));
 
         // Force KPasswdServer to process the request now, otherwise the checkAndFillDialog needs a timer too...
@@ -515,13 +503,13 @@ private:
             QVERIFY(QSignalSpy(&server, sigQueryAuthInfoResult).wait(1000));
         }
 
-        while ((spy.count()-1) < infos.count()) {
+        while ((spy.count() - 1) < infos.count()) {
             QVERIFY(QSignalSpy(&server, sigCheckAuthInfoResult).wait(1000));
         }
 
-        for(int i = 0, count = spy.count(); i < count; ++i) {
+        for (int i = 0, count = spy.count(); i < count; ++i) {
             QCOMPARE(spy[i][0].toLongLong(), idList.at(i));
-            //QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
+            // QCOMPARE(spy[0][1].toLongLong(), 3LL); // seqNr
             KIO::AuthInfo result = spy[i][2].value<KIO::AuthInfo>();
             QCOMPARE(result.username, filledInfo.username);
             QCOMPARE(result.password, filledInfo.password);
@@ -531,10 +519,11 @@ private:
     }
 
 protected Q_SLOTS:
-    void checkAndFillDialog(const KIO::AuthInfo& info, const KIO::AuthInfo& filledInfo, QDialog::DialogCode code)
+    void checkAndFillDialog(const KIO::AuthInfo &info, const KIO::AuthInfo &filledInfo, QDialog::DialogCode code)
     {
-        Q_FOREACH(QWidget *widget, QApplication::topLevelWidgets()) {
-            if (KPasswordDialog* dialog = qobject_cast<KPasswordDialog *>(widget)) {
+        const QList<QWidget *> widgetsList = QApplication::topLevelWidgets();
+        for (QWidget *widget : widgetsList) {
+            if (KPasswordDialog *dialog = qobject_cast<KPasswordDialog *>(widget)) {
                 if (code == QDialog::Accepted) {
                     QCOMPARE(dialog->username(), getUserNameFrom(info));
                     QCOMPARE(dialog->password(), info.password);
@@ -550,8 +539,9 @@ protected Q_SLOTS:
 
     void checkRetryDialog(QDialogButtonBox::StandardButton code = s_buttonYes)
     {
-        Q_FOREACH(QWidget *widget, QApplication::topLevelWidgets()) {
-            QDialog* dialog = qobject_cast<QDialog*>(widget);
+        const QList<QWidget *> widgetsList = QApplication::topLevelWidgets();
+        for (QWidget *widget : widgetsList) {
+            QDialog *dialog = qobject_cast<QDialog *>(widget);
             if (dialog && !dialog->inherits("KPasswordDialog")) {
                 dialog->done(code);
                 return;
@@ -561,6 +551,6 @@ protected Q_SLOTS:
     }
 };
 
-QTEST_MAIN( KPasswdServerTest )
+QTEST_MAIN(KPasswdServerTest)
 
 #include "kpasswdservertest.moc"
