@@ -14,16 +14,17 @@
 #include "searchproviderdlg.h"
 
 #include <KBuildSycocaProgressDialog>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QFile>
+#include <QPointer>
 #include <QSortFilterProxyModel>
 
-//BEGIN ProvidersModel
+// BEGIN ProvidersModel
 
 ProvidersModel::~ProvidersModel()
 {
@@ -74,32 +75,39 @@ bool ProvidersModel::setData(const QModelIndex &index, const QVariant &value, in
 
 QVariant ProvidersModel::data(const QModelIndex &index, int role) const
 {
-    if (index.isValid()) {
-        if (role == Qt::CheckStateRole && index.column() == Preferred) {
-            return m_favoriteEngines.contains(m_providers.at(index.row())->desktopEntryName()) ? Qt::Checked : Qt::Unchecked;
-        }
+    if (!index.isValid()) {
+        return QVariant();
+    }
 
-        if (role == Qt::DisplayRole) {
-            if (index.column() == Name) {
-                return m_providers.at(index.row())->name();
-            }
-            if (index.column() == Shortcuts) {
-                return m_providers.at(index.row())->keys().join(QLatin1Char(','));
-            }
-        }
+    if (role == Qt::CheckStateRole && index.column() == Preferred) {
+        return m_favoriteEngines.contains(m_providers.at(index.row())->desktopEntryName()) ? Qt::Checked : Qt::Unchecked;
+    }
 
-        if (role == Qt::ToolTipRole || role == Qt::WhatsThisRole) {
-            if (index.column() == Preferred) {
-                return xi18nc("@info:tooltip", "Check this box to select the highlighted web search keyword "
-                                               "as preferred.<nl/>Preferred web search keywords are used in "
-                                               "places where only a few select keywords can be shown "
-                                               "at one time.");
-            }
-        }
+    if (role == Qt::DecorationRole && index.column() == Name) {
+        return QIcon::fromTheme(m_providers.at(index.row())->iconName());
+    }
 
-        if (role == Qt::UserRole) {
-            return index.row();//a nice way to bypass proxymodel
+    if (role == Qt::DisplayRole) {
+        if (index.column() == Name) {
+            return m_providers.at(index.row())->name();
         }
+        if (index.column() == Shortcuts) {
+            return m_providers.at(index.row())->keys().join(QLatin1Char(','));
+        }
+    }
+
+    if (role == Qt::ToolTipRole || role == Qt::WhatsThisRole) {
+        if (index.column() == Preferred) {
+            return xi18nc("@info:tooltip",
+                          "Check this box to select the highlighted web search keyword "
+                          "as preferred.<nl/>Preferred web search keywords are used in "
+                          "places where only a few select keywords can be shown "
+                          "at one time.");
+        }
+    }
+
+    if (role == Qt::UserRole) {
+        return index.row(); // a nice way to bypass proxymodel
     }
 
     return QVariant();
@@ -162,7 +170,7 @@ void ProvidersModel::addProvider(SearchProvider *p)
 void ProvidersModel::changeProvider(SearchProvider *p)
 {
     const int row = m_providers.indexOf(p);
-    Q_EMIT dataChanged(index(row, 0), index(row, ColumnCount-1));
+    Q_EMIT dataChanged(index(row, 0), index(row, ColumnCount - 1));
     Q_EMIT dataModified();
 }
 
@@ -171,9 +179,9 @@ QStringList ProvidersModel::favoriteEngines() const
     return QStringList(m_favoriteEngines.cbegin(), m_favoriteEngines.cend());
 }
 
-//END ProvidersModel
+// END ProvidersModel
 
-//BEGIN ProvidersListModel
+// BEGIN ProvidersListModel
 ProvidersListModel::ProvidersListModel(QList<SearchProvider *> &providers, QObject *parent)
     : QAbstractListModel(parent)
     , m_providers(providers)
@@ -182,21 +190,31 @@ ProvidersListModel::ProvidersListModel(QList<SearchProvider *> &providers, QObje
 
 QVariant ProvidersListModel::data(const QModelIndex &index, int role) const
 {
-    if (index.isValid()) {
-        if (role == Qt::DisplayRole) {
-            if (index.row() == m_providers.size()) {
-                return i18nc("@item:inlistbox No default web search keyword", "None");
-            }
-            return m_providers.at(index.row())->name();
-        }
-
-        if (role == ShortNameRole) {
-            if (index.row() == m_providers.size()) {
-                return QString();
-            }
-            return m_providers.at(index.row())->desktopEntryName();
-        }
+    if (!index.isValid()) {
+        return QVariant();
     }
+
+    const int row = index.row();
+    const bool noProvider = (row == m_providers.size()); // `None` is the last item
+
+    switch (role) {
+    case Qt::DisplayRole:
+        if (noProvider) {
+            return i18nc("@item:inlistbox No default web search keyword", "None");
+        }
+        return m_providers.at(index.row())->name();
+    case ShortNameRole:
+        if (noProvider) {
+            return QString();
+        }
+        return m_providers.at(index.row())->desktopEntryName();
+    case Qt::DecorationRole:
+        if (noProvider) {
+            return QIcon::fromTheme(QStringLiteral("empty"));
+        }
+        return QIcon::fromTheme(m_providers.at(index.row())->iconName());
+    }
+
     return QVariant();
 }
 
@@ -208,7 +226,7 @@ int ProvidersListModel::rowCount(const QModelIndex &parent) const
     return m_providers.size() + 1;
 }
 
-//END ProvidersListModel
+// END ProvidersListModel
 
 static QSortFilterProxyModel *wrapInProxyModel(QAbstractItemModel *model)
 {
@@ -221,10 +239,13 @@ static QSortFilterProxyModel *wrapInProxyModel(QAbstractItemModel *model)
     return proxyModel;
 }
 
-FilterOptions::FilterOptions(QWidget *parent)
-    : KCModule(parent)
+FilterOptions::FilterOptions(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
     , m_providersModel(new ProvidersModel(this))
 {
+    // Used for tab text in the KCM
+    setWindowTitle(i18n("Search F&ilters"));
+
     m_dlg.setupUi(this);
 
     QSortFilterProxyModel *searchProviderModel = wrapInProxyModel(m_providersModel);
@@ -243,34 +264,34 @@ FilterOptions::FilterOptions(QWidget *parent)
     connect(m_dlg.pbNew, &QAbstractButton::clicked, this, &FilterOptions::addSearchProvider);
     connect(m_dlg.pbDelete, &QAbstractButton::clicked, this, &FilterOptions::deleteSearchProvider);
     connect(m_dlg.pbChange, &QAbstractButton::clicked, this, &FilterOptions::changeSearchProvider);
-    connect(m_dlg.lvSearchProviders->selectionModel(), &QItemSelectionModel::currentChanged,
-            this, &FilterOptions::updateSearchProviderEditingButons);
+    connect(m_dlg.lvSearchProviders->selectionModel(), &QItemSelectionModel::currentChanged, this, &FilterOptions::updateSearchProviderEditingButons);
     connect(m_dlg.lvSearchProviders, &QAbstractItemView::doubleClicked, this, &FilterOptions::changeSearchProvider);
     connect(m_dlg.searchLineEdit, &QLineEdit::textEdited, searchProviderModel, &QSortFilterProxyModel::setFilterFixedString);
 }
 
 QString FilterOptions::quickHelp() const
 {
-    return xi18nc("@info:whatsthis", "<para>In this module you can configure the web search keywords feature. "
-                                     "Web search keywords allow you to quickly search or lookup words on "
-                                     "the Internet. For example, to search for information about the "
-                                     "KDE project using the Google engine, you simply type <emphasis>gg:KDE</emphasis> "
-                                     "or <emphasis>google:KDE</emphasis>.</para>"
-                                     "<para>If you select a default search engine, then you can search for "
-                                     "normal words or phrases by simply typing them into the input widget "
-                                     "of applications that have built-in support for such a feature, e.g "
-                                     "Konqueror.</para>");
+    return xi18nc("@info:whatsthis",
+                  "<para>In this module you can configure the web search keywords feature. "
+                  "Web search keywords allow you to quickly search or lookup words on "
+                  "the Internet. For example, to search for information about the "
+                  "KDE project using the Google engine, you simply type <emphasis>gg:KDE</emphasis> "
+                  "or <emphasis>google:KDE</emphasis>.</para>"
+                  "<para>If you select a default search engine, then you can search for "
+                  "normal words or phrases by simply typing them into the input widget "
+                  "of applications that have built-in support for such a feature, e.g "
+                  "Konqueror.</para>");
 }
 
 void FilterOptions::setDefaultEngine(int index)
 {
     QSortFilterProxyModel *proxy = qobject_cast<QSortFilterProxyModel *>(m_dlg.cmbDefaultEngine->model());
     if (index == -1) {
-        index = proxy->rowCount()-1;//"None" is the last
+        index = proxy->rowCount() - 1; //"None" is the last
     }
     const QModelIndex modelIndex = proxy->mapFromSource(proxy->sourceModel()->index(index, 0));
     m_dlg.cmbDefaultEngine->setCurrentIndex(modelIndex.row());
-    m_dlg.cmbDefaultEngine->view()->setCurrentIndex(modelIndex); //TODO: remove this when Qt bug is fixed
+    m_dlg.cmbDefaultEngine->view()->setCurrentIndex(modelIndex); // TODO: remove this when Qt bug is fixed
 }
 
 void FilterOptions::load()
@@ -279,7 +300,7 @@ void FilterOptions::load()
     KConfigGroup group = config.group("General");
 
     const QString defaultSearchEngine = group.readEntry("DefaultWebShortcut");
-    const QStringList favoriteEngines = group.readEntry("PreferredWebShortcuts", DEFAULT_PREFERRED_SEARCH_PROVIDERS);
+    const QStringList favoriteEngines = group.readEntry("PreferredWebShortcuts", KURISearchFilterEngine::defaultSearchProviders());
 
     const QList<SearchProvider *> allProviders = m_registry.findAll();
     QList<SearchProvider *> providers;
@@ -289,7 +310,7 @@ void FilterOptions::load()
         }
     }
 
-    int defaultProviderIndex = providers.size(); //default is "None", it is last in the list
+    int defaultProviderIndex = providers.size(); // default is "None", it is last in the list
 
     for (SearchProvider *provider : qAsConst(providers)) {
         if (defaultSearchEngine == provider->desktopEntryName()) {
@@ -356,7 +377,8 @@ void FilterOptions::save()
         service.writeEntry("Hidden", false); // we might be overwriting a hidden entry
     }
 
-    const QStringList servicesDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/searchproviders/"), QStandardPaths::LocateDirectory);
+    const QStringList servicesDirs =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/searchproviders/"), QStandardPaths::LocateDirectory);
     for (const QString &providerName : qAsConst(m_deletedProviders)) {
         QStringList matches;
         for (const QString &dir : servicesDirs) {
@@ -405,7 +427,7 @@ void FilterOptions::defaults()
 {
     m_dlg.cbEnableShortcuts->setChecked(true);
     m_dlg.cbUseSelectedShortcutsOnly->setChecked(false);
-    m_providersModel->setFavoriteProviders(DEFAULT_PREFERRED_SEARCH_PROVIDERS);
+    m_providersModel->setFavoriteProviders(KURISearchFilterEngine::defaultSearchProviders());
     setDelimiter(':');
     setDefaultEngine(-1);
 }
@@ -444,8 +466,7 @@ void FilterOptions::deleteSearchProvider()
 
 void FilterOptions::updateSearchProviderEditingButons()
 {
-    const bool enable = (m_dlg.cbEnableShortcuts->isChecked()
-                         && m_dlg.lvSearchProviders->currentIndex().isValid());
+    const bool enable = (m_dlg.cbEnableShortcuts->isChecked() && m_dlg.lvSearchProviders->currentIndex().isValid());
     m_dlg.pbChange->setEnabled(enable);
     m_dlg.pbDelete->setEnabled(enable);
 }
