@@ -10,33 +10,30 @@
 #include "accessmanagerreply_p.h"
 #include "accessmanager.h"
 #include "job.h"
-#include "scheduler.h"
 #include "kio_widgets_debug.h"
+#include "scheduler.h"
 
-#include <kurlauthorized.h>
 #include <kprotocolinfo.h>
+#include <kurlauthorized.h>
+
 #include <QMimeDatabase>
-
-#include <QtMath>
 #include <QSslConfiguration>
+#include <QtMath>
 
-#define QL1S(x)  QLatin1String(x)
-#define QL1C(x)  QLatin1Char(x)
 
 namespace KDEPrivate
 {
-
 AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op,
                                        const QNetworkRequest &request,
                                        KIO::SimpleJob *kioJob,
                                        bool emitReadyReadOnMetaDataChange,
                                        QObject *parent)
-    : QNetworkReply(parent),
-      m_offset(0),
-      m_metaDataRead(false),
-      m_ignoreContentDisposition(false),
-      m_emitReadyReadOnMetaDataChange(emitReadyReadOnMetaDataChange),
-      m_kioJob(kioJob)
+    : QNetworkReply(parent)
+    , m_offset(0)
+    , m_metaDataRead(false)
+    , m_ignoreContentDisposition(false)
+    , m_emitReadyReadOnMetaDataChange(emitReadyReadOnMetaDataChange)
+    , m_kioJob(kioJob)
 
 {
     setRequest(request);
@@ -49,17 +46,15 @@ AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op
         setSslConfiguration(request.sslConfiguration());
     }
 
-    connect(kioJob, SIGNAL(redirection(KIO::Job*,QUrl)), SLOT(slotRedirection(KIO::Job*,QUrl)));
-    connect(kioJob, QOverload<KJob*,ulong>::of(&KJob::percent), this, &AccessManagerReply::slotPercent);
+    connect(kioJob, SIGNAL(redirection(KIO::Job *, QUrl)), SLOT(slotRedirection(KIO::Job *, QUrl)));
+    connect(kioJob, &KJob::percentChanged, this, &AccessManagerReply::slotPercent);
 
     if (qobject_cast<KIO::StatJob *>(kioJob)) {
         connect(kioJob, &KJob::result, this, &AccessManagerReply::slotStatResult);
     } else {
         connect(kioJob, &KJob::result, this, &AccessManagerReply::slotResult);
-        connect(kioJob, SIGNAL(data(KIO::Job*,QByteArray)),
-                SLOT(slotData(KIO::Job*,QByteArray)));
-        connect(kioJob, SIGNAL(mimeTypeFound(KIO::Job*,QString)),
-                SLOT(slotMimeType(KIO::Job*,QString)));
+        connect(kioJob, SIGNAL(data(KIO::Job *, QByteArray)), SLOT(slotData(KIO::Job *, QByteArray)));
+        connect(kioJob, SIGNAL(mimeTypeFound(KIO::Job *, QString)), SLOT(slotMimeType(KIO::Job *, QString)));
     }
 }
 
@@ -69,11 +64,11 @@ AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op
                                        const QUrl &url,
                                        const KIO::MetaData &metaData,
                                        QObject *parent)
-    : QNetworkReply(parent),
-      m_data(data),
-      m_offset(0),
-      m_ignoreContentDisposition(false),
-      m_emitReadyReadOnMetaDataChange(false)
+    : QNetworkReply(parent)
+    , m_data(data)
+    , m_offset(0)
+    , m_ignoreContentDisposition(false)
+    , m_emitReadyReadOnMetaDataChange(false)
 {
     setRequest(request);
     setOpenMode(QIODevice::ReadOnly);
@@ -94,8 +89,8 @@ AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op
                                        QNetworkReply::NetworkError errorCode,
                                        const QString &errorMessage,
                                        QObject *parent)
-    : QNetworkReply(parent),
-      m_offset(0)
+    : QNetworkReply(parent)
+    , m_offset(0)
 {
     setRequest(request);
     setOpenMode(QIODevice::ReadOnly);
@@ -185,22 +180,18 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
     }
 
     // Set the raw header information...
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList httpHeaders(metaData.value(QStringLiteral("HTTP-Headers")).split(QL1C('\n'), QString::SkipEmptyParts));
-#else
-    const QStringList httpHeaders(metaData.value(QStringLiteral("HTTP-Headers")).split(QL1C('\n'), Qt::SkipEmptyParts));
-#endif
+    const QStringList httpHeaders(metaData.value(QStringLiteral("HTTP-Headers")).split(QLatin1Char('\n'), Qt::SkipEmptyParts));
     if (httpHeaders.isEmpty()) {
         const auto charSetIt = metaData.constFind(QStringLiteral("charset"));
         if (charSetIt != metaData.constEnd()) {
             QString mimeType = header(QNetworkRequest::ContentTypeHeader).toString();
             mimeType += QLatin1String(" ; charset=") + *charSetIt;
-            //qDebug() << "changed content-type to" << mimeType;
+            // qDebug() << "changed content-type to" << mimeType;
             setHeader(QNetworkRequest::ContentTypeHeader, mimeType.toUtf8());
         }
     } else {
         for (const QString &httpHeader : httpHeaders) {
-            int index = httpHeader.indexOf(QL1C(':'));
+            int index = httpHeader.indexOf(QLatin1Char(':'));
             // Handle HTTP status line...
             if (index == -1) {
                 // Except for the status line, all HTTP header must be an nvpair of
@@ -209,11 +200,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                     continue;
                 }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                QStringList statusLineAttrs(httpHeader.split(QL1C(' '), QString::SkipEmptyParts));
-#else
-                QStringList statusLineAttrs(httpHeader.split(QL1C(' '), Qt::SkipEmptyParts));
-#endif
+                QStringList statusLineAttrs(httpHeader.split(QLatin1Char(' '), Qt::SkipEmptyParts));
                 if (statusLineAttrs.count() > 1) {
                     setAttribute(QNetworkRequest::HttpStatusCodeAttribute, statusLineAttrs.at(1));
                 }
@@ -233,15 +220,13 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 continue;
             }
 
-            if (headerName.startsWith(QLatin1String("content-disposition"), Qt::CaseInsensitive) &&
-                    ignoreContentDisposition(metaData)) {
+            if (headerName.startsWith(QLatin1String("content-disposition"), Qt::CaseInsensitive) && ignoreContentDisposition(metaData)) {
                 continue;
             }
 
             // Without overriding the corrected mime-type sent by kio_http, add
             // back the "charset=" portion of the content-type header if present.
             if (headerName.startsWith(QLatin1String("content-type"), Qt::CaseInsensitive)) {
-
                 QString mimeType(header(QNetworkRequest::ContentTypeHeader).toString());
 
                 if (m_ignoreContentDisposition) {
@@ -258,13 +243,13 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 }
 
                 if (!headerValue.contains(mimeType, Qt::CaseInsensitive)) {
-                    index = headerValue.indexOf(QL1C(';'));
+                    index = headerValue.indexOf(QLatin1Char(';'));
                     if (index == -1) {
                         headerValue = mimeType;
                     } else {
                         headerValue.replace(0, index, mimeType);
                     }
-                    //qDebug() << "Changed mime-type from" << mimeType << "to" << headerValue;
+                    // qDebug() << "Changed mime-type from" << mimeType << "to" << headerValue;
                 }
             }
             setRawHeader(headerName.trimmed().toUtf8(), headerValue.trimmed().toUtf8());
@@ -277,7 +262,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
 
 void AccessManagerReply::setIgnoreContentDisposition(bool on)
 {
-    //qDebug() << on;
+    // qDebug() << on;
     m_ignoreContentDisposition = on;
 }
 
@@ -287,7 +272,7 @@ void AccessManagerReply::putOnHold()
         return;
     }
 
-    //qDebug() << m_kioJob << m_data;
+    // qDebug() << m_kioJob << m_data;
     m_kioJob.data()->disconnect(this);
     m_kioJob.data()->putOnHold();
     m_kioJob.clear();
@@ -297,8 +282,7 @@ void AccessManagerReply::putOnHold()
 bool AccessManagerReply::isLocalRequest(const QUrl &url)
 {
     const QString scheme(url.scheme());
-    return (KProtocolInfo::isKnownProtocol(scheme) &&
-            KProtocolInfo::protocolClass(scheme).compare(QStringLiteral(":local"), Qt::CaseInsensitive) == 0);
+    return (KProtocolInfo::isKnownProtocol(scheme) && KProtocolInfo::protocolClass(scheme).compare(QStringLiteral(":local"), Qt::CaseInsensitive) == 0);
 }
 
 void AccessManagerReply::readHttpResponseHeaders(KIO::Job *job)
@@ -313,14 +297,14 @@ void AccessManagerReply::readHttpResponseHeaders(KIO::Job *job)
         if (isLocalRequest(url())) {
             setHeader(QNetworkRequest::ContentLengthHeader, job->totalAmount(KJob::Bytes));
             setAttribute(QNetworkRequest::HttpStatusCodeAttribute, QStringLiteral("200"));
-            emit metaDataChanged();
+            Q_EMIT metaDataChanged();
         }
         return;
     }
 
     setHeaderFromMetaData(metaData);
     m_metaDataRead = true;
-    emit metaDataChanged();
+    Q_EMIT metaDataChanged();
 }
 
 int AccessManagerReply::jobError(KJob *kJob)
@@ -412,16 +396,16 @@ void AccessManagerReply::slotData(KIO::Job *kioJob, const QByteArray &data)
 
     m_data += data;
 
-    emit readyRead();
+    Q_EMIT readyRead();
 }
 
 void AccessManagerReply::slotMimeType(KIO::Job *kioJob, const QString &mimeType)
 {
-    //qDebug() << kioJob << mimeType;
+    // qDebug() << kioJob << mimeType;
     setHeader(QNetworkRequest::ContentTypeHeader, mimeType.toUtf8());
     readHttpResponseHeaders(kioJob);
     if (m_emitReadyReadOnMetaDataChange) {
-        emit readyRead();
+        Q_EMIT readyRead();
     }
 }
 
@@ -434,11 +418,7 @@ void AccessManagerReply::slotResult(KJob *kJob)
         setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::KioError), errcode);
         if (errcode && errcode != KIO::ERR_NO_CONTENT) {
             const auto networkError = error();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            emit error(networkError);
-#else
-            emit errorOccurred(networkError);
-#endif
+            Q_EMIT errorOccurred(networkError);
         }
     }
 
@@ -454,11 +434,7 @@ void AccessManagerReply::slotStatResult(KJob *kJob)
 {
     if (jobError(kJob)) {
         const auto networkError = error();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        emit error(networkError);
-#else
-        emit errorOccurred(networkError);
-#endif
+        Q_EMIT errorOccurred(networkError);
         emitFinished(true);
         return;
     }
@@ -466,7 +442,7 @@ void AccessManagerReply::slotStatResult(KJob *kJob)
     KIO::StatJob *statJob = qobject_cast<KIO::StatJob *>(kJob);
     Q_ASSERT(statJob);
 
-    KIO::UDSEntry entry =  statJob->statResult();
+    KIO::UDSEntry entry = statJob->statResult();
     QString mimeType = entry.stringValue(KIO::UDSEntry::UDS_MIME_TYPE);
     if (mimeType.isEmpty() && entry.isDir()) {
         mimeType = QStringLiteral("inode/directory");
@@ -485,15 +461,11 @@ void AccessManagerReply::slotRedirection(KIO::Job *job, const QUrl &u)
         qCWarning(KIO_WIDGETS) << "Redirection from" << url() << "to" << u << "REJECTED by policy!";
         setError(QNetworkReply::ContentAccessDenied, u.toString());
         const auto networkError = error();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        emit error(networkError);
-#else
-        emit errorOccurred(networkError);
-#endif
+        Q_EMIT errorOccurred(networkError);
         return;
     }
     setAttribute(QNetworkRequest::RedirectionTargetAttribute, QUrl(u));
-    if (job->queryMetaData(QStringLiteral("redirect-to-get")) == QL1S("true")) {
+    if (job->queryMetaData(QStringLiteral("redirect-to-get")) == QLatin1String("true")) {
         setOperation(QNetworkAccessManager::GetOperation);
     }
 }
@@ -502,19 +474,17 @@ void AccessManagerReply::slotPercent(KJob *job, unsigned long percent)
 {
     qulonglong bytesTotal = job->totalAmount(KJob::Bytes);
     qulonglong bytesProcessed = (bytesTotal * percent) / 100;
-    if (operation() == QNetworkAccessManager::PutOperation ||
-            operation() == QNetworkAccessManager::PostOperation) {
-        emit uploadProgress(bytesProcessed, bytesTotal);
+    if (operation() == QNetworkAccessManager::PutOperation || operation() == QNetworkAccessManager::PostOperation) {
+        Q_EMIT uploadProgress(bytesProcessed, bytesTotal);
         return;
     }
-    emit downloadProgress(bytesProcessed, bytesTotal);
+    Q_EMIT downloadProgress(bytesProcessed, bytesTotal);
 }
 
 void AccessManagerReply::emitFinished(bool state, Qt::ConnectionType type)
 {
     setFinished(state);
-    emit QMetaObject::invokeMethod(this, "finished", type);
+    Q_EMIT QMetaObject::invokeMethod(this, "finished", type);
 }
 
 }
-
