@@ -42,7 +42,7 @@ class QWidget;
  * add_library(foothumbnail MODULE ${foothumbnail_SRCS})
  * target_link_libraries(foothumbnail PRIVATE KF5::KIOWidgets)
  *
- * install(TARGETS foothumbnail DESTINATION ${PLUGIN_INSTALL_DIR})
+ * install(TARGETS foothumbnail DESTINATION ${KDE_INSTALL_PLUGINDIR})
  * \endcode
  *
  * You also need to create a desktop file describing the thumbnailer.  For
@@ -59,11 +59,11 @@ class QWidget;
  *
  * Of course, you will need to install it:
  * \code
- * install(FILES foothumbcreator.desktop DESTINATION ${SERVICES_INSTALL_DIR})
+ * install(FILES foothumbcreator.desktop DESTINATION ${KDE_INSTALL_KSERVICES5DIR})
  * \endcode
  *
- * Note that you can supply a comma-separated list of mimetypes to the MimeTypes
- * entry, naming all mimetypes your ThumbCreator supports. You can also use
+ * Note that you can supply a comma-separated list of MIME types to the MimeTypes
+ * entry, naming all MIME types your ThumbCreator supports. You can also use
  * simple wildcards, like
  * \htmlonly "text/&#42;".\endhtmlonly\latexonly text/$\ast$.\endlatexonly
  *
@@ -91,11 +91,12 @@ public:
      * @see flags()
      */
     enum Flags {
-        None = 0,      /**< No hints. */
+        None = 0, /**< No hints. */
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 32)
-        DrawFrame = 1, /**< \deprecated since 5.32. Used to paint a frame around the preview, but applications take care of that nowadays. */
+        DrawFrame KIOWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 32, "See API dox") =
+            1, /**< \deprecated since 5.32. Used to paint a frame around the preview, but applications take care of that nowadays. */
 #endif
-        BlendIcon = 2  /**< The mimetype icon should be blended over the preview. */
+        BlendIcon = 2, /**< The MIME type icon should be blended over the preview. */
     };
 
     /**
@@ -164,8 +165,7 @@ public:
  * @since 4.7
  * @deprecated since 5.0, use ThumbCreator
  */
-class KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use ThumbCreator")
-KIOWIDGETS_EXPORT ThumbCreatorV2 : public ThumbCreator
+class KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use ThumbCreator") KIOWIDGETS_EXPORT ThumbCreatorV2 : public ThumbCreator
 {
 public:
     virtual ~ThumbCreatorV2();
